@@ -23,9 +23,9 @@
  * SPDX-License-Identifier: curl
  *
  ***************************************************************************/
-#include "../curl_setup.h"
+#include "curl_setup.h"
 
-#include "multibyte.h"
+#include "curlx/multibyte.h"
 
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>  /* for open() and attributes */
@@ -34,6 +34,7 @@
 int curlx_fseek(void *stream, curl_off_t offset, int whence);
 
 #ifdef _WIN32
+#include <sys/stat.h>  /* for _fstati64(), struct _stati64 */
 #ifndef CURL_WINDOWS_UWP
 HANDLE curlx_CreateFile(const char *filename,
                         DWORD dwDesiredAccess,
@@ -43,25 +44,33 @@ HANDLE curlx_CreateFile(const char *filename,
                         DWORD dwFlagsAndAttributes,
                         HANDLE hTemplateFile);
 #endif /* !CURL_WINDOWS_UWP */
+#define curlx_fstat             _fstati64
+#define curlx_struct_stat       struct _stati64
 FILE *curlx_win32_fopen(const char *filename, const char *mode);
 FILE *curlx_win32_freopen(const char *filename, const char *mode, FILE *fh);
-int curlx_win32_stat(const char *path, struct_stat *buffer);
+int curlx_win32_stat(const char *path, curlx_struct_stat *buffer);
 int curlx_win32_open(const char *filename, int oflag, ...);
 int curlx_win32_rename(const char *oldpath, const char *newpath);
-#define CURLX_FOPEN_LOW(fname, mode)       curlx_win32_fopen(fname, mode)
-#define CURLX_FREOPEN_LOW(fname, mode, fh) curlx_win32_freopen(fname, mode, fh)
-#define curlx_stat(fname, stp)             curlx_win32_stat(fname, stp)
-#define curlx_open                         curlx_win32_open
-#define curlx_rename                       curlx_win32_rename
+#define CURLX_FOPEN_LOW         curlx_win32_fopen
+#define CURLX_FREOPEN_LOW       curlx_win32_freopen
+#define CURLX_FDOPEN_LOW        _fdopen
+#define curlx_stat              curlx_win32_stat
+#define curlx_open              curlx_win32_open
+#define curlx_close             _close
+#define curlx_rename            curlx_win32_rename
 #else
-#define CURLX_FOPEN_LOW                    fopen
-#define CURLX_FREOPEN_LOW                  freopen
-#define curlx_stat(fname, stp)             stat(fname, stp)
-#define curlx_open                         open
-#define curlx_rename                       rename
+#define curlx_fstat             fstat
+#define curlx_struct_stat       struct stat
+#define CURLX_FOPEN_LOW         fopen
+#define CURLX_FREOPEN_LOW       freopen
+#define CURLX_FDOPEN_LOW        fdopen
+#define curlx_stat              stat
+#define curlx_open              open
+#define curlx_close             close
+#define curlx_rename            rename
 #endif
 
-#ifdef CURLDEBUG
+#ifdef CURL_MEMDEBUG
 #define curlx_fopen(file, mode) curl_dbg_fopen(file, mode, __LINE__, __FILE__)
 #define curlx_freopen(file, mode, fh) \
   curl_dbg_freopen(file, mode, fh, __LINE__, __FILE__)
@@ -71,7 +80,7 @@ int curlx_win32_rename(const char *oldpath, const char *newpath);
 #else
 #define curlx_fopen             CURLX_FOPEN_LOW
 #define curlx_freopen           CURLX_FREOPEN_LOW
-#define curlx_fdopen            fdopen
+#define curlx_fdopen            CURLX_FDOPEN_LOW
 #define curlx_fclose            fclose
 #endif
 
